import type { AppRouteRecordRaw, AppRouteModule } from '@/router/types';
import { HomeOutlined } from '@ant-design/icons-vue';
import { routerList } from './routerList';

// 权限管理
const PermissionRoute : AppRouteRecordRaw = {
	path: '/permission',
	name: 'permission',
	component: routerList.Permission,
	meta: {
		title: '权限管理',
		icon: HomeOutlined
	},
	children: [
		{
			path: '/role',
			name: 'role',
			component: routerList.ROLE,
			meta: {
				title: '角色管理',
				icon: HomeOutlined
			}
		},
		{
			path: '/account',
			name: 'account',
			component: routerList.Account,
			meta: {
				title: '账号管理',
				icon: HomeOutlined
			}
		},
		{
			path: '/permission/list',
			name: 'list',
			component: routerList.List,
			meta: {
				title: '权限管理',
				icon: HomeOutlined
			}
		}
	]
};


// 企业相关
const CompanyRoute : AppRouteRecordRaw = {
	path: '/company',
	name: 'company',
	component: routerList.Company,
	meta: {
		title: '企业管理',
		icon: HomeOutlined
	},
	children: [{
			path: '/member',
			name: 'member',
			component: routerList.Member,
			meta: {
				title: '企业列表',
				icon: HomeOutlined
			},
		},
		{
			path: '/vip',
			name: 'vip',
			component: routerList.Vip,
			meta: {
				title: 'VIP管理',
				icon: HomeOutlined
			},
		},
		{
			path: '/job',
			name: 'job',
			component: routerList.Job,
			meta: {
				title: '职位管理',
				icon: HomeOutlined
			},
		},
		{
			path: '/department',
			name: 'department',
			component: routerList.Department,
			meta: {
				title: '部门管理',
				icon: HomeOutlined
			},
		},
	]
};

// 求职者管理
const JokSeekerRoute : AppRouteRecordRaw = {
	path: '/job-seeker',
	name: 'jobSeeker',
	component: routerList.JobSeeker,
	meta: {
		title: '求职者管理',
		icon: HomeOutlined
	},
	children: [
		{
			path: '/resume',
			name: 'jobResume',
			component: routerList.JobResume,
			meta: {
				title: '简历列表',
				icon: HomeOutlined
			},
		},
	]
};

// 招聘会管理
const JokFairRoute : AppRouteRecordRaw = {
	path: '/job-fair',
	name: 'jobFair',
	component: routerList.JokFair,
	meta: {
		title: '招聘会管理',
		icon: HomeOutlined
	},
	children: [
		{
			path: '/job/fair/list',
			name: 'jobFairList',
			component: routerList.JobList,
			meta: {
				title: '招聘会列表',
				icon: HomeOutlined
			},
		},
	]
};

// 资讯管理
const InformationRoute : AppRouteRecordRaw = {
	path: '/information',
	name: 'information',
	component: routerList.Information,
	meta: {
		title: '资讯管理',
		icon: HomeOutlined
	},
	children: [
		{
			path: '/section',
			name: 'section',
			component: routerList.InformationSection,
			meta: {
				title: '栏目/频道',
				icon: HomeOutlined
			},
		},
		{
			path: '/article',
			name: 'article',
			component: routerList.InformationArticle,
			meta: {
				title: '文章列表',
				icon: HomeOutlined
			},
		}
	],
	
};

export const routesModuleList : AppRouteModule[] = [CompanyRoute, JokSeekerRoute, JokFairRoute, InformationRoute, PermissionRoute];